Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(830)

Unified Diff: content/browser/frame_host/navigation_request.h

Issue 2813243002: network service: pass PlzNavigate resulting data via mojo data pipe (Closed)
Patch Set: ahem Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/frame_host/navigation_request.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/navigation_request.h
diff --git a/content/browser/frame_host/navigation_request.h b/content/browser/frame_host/navigation_request.h
index 24980b97da4696d2062a99ef41757bc9237454ce..095b77f53be296d0f25bc142816eb584d9934f7f 100644
--- a/content/browser/frame_host/navigation_request.h
+++ b/content/browser/frame_host/navigation_request.h
@@ -17,6 +17,7 @@
#include "content/common/navigation_params.h"
#include "content/public/browser/navigation_throttle.h"
#include "content/public/common/previews_state.h"
+#include "mojo/public/cpp/system/data_pipe.h"
namespace content {
@@ -182,6 +183,7 @@ class CONTENT_EXPORT NavigationRequest : public NavigationURLLoaderDelegate {
const scoped_refptr<ResourceResponse>& response) override;
void OnResponseStarted(const scoped_refptr<ResourceResponse>& response,
std::unique_ptr<StreamHandle> body,
+ mojo::ScopedDataPipeConsumerHandle consumer_handle,
const SSLStatus& ssl_status,
std::unique_ptr<NavigationData> navigation_data,
const GlobalRequestID& request_id,
@@ -248,10 +250,12 @@ class CONTENT_EXPORT NavigationRequest : public NavigationURLLoaderDelegate {
std::unique_ptr<NavigationHandleImpl> navigation_handle_;
// Holds the ResourceResponse and the StreamHandle for the navigation while
// the WillProcessResponse checks are performed by the NavigationHandle.
scoped_refptr<ResourceResponse> response_;
std::unique_ptr<StreamHandle> body_;
+ mojo::ScopedDataPipeConsumerHandle handle_;
base::Closure on_start_checks_complete_closure_;
« no previous file with comments | « no previous file | content/browser/frame_host/navigation_request.cc » ('j') | no next file with comments »
@@ -248,10 +250,12 @@ class CONTENT_EXPORT NavigationRequest : public NavigationURLLoaderDelegate {
std::unique_ptr<NavigationHandleImpl> navigation_handle_;
- // Holds the ResourceResponse and the StreamHandle for the navigation while
- // the WillProcessResponse checks are performed by the NavigationHandle.
+ // Holds the ResourceResponse and the StreamHandle (or
+ // DataPipeConsumerHandle) for the navigation while the WillProcessResponse
+ // checks are performed by the NavigationHandle.
scoped_refptr<ResourceResponse> response_;
std::unique_ptr<StreamHandle> body_;

Powered by Google App Engine
This is Rietveld 408576698